# Copyright 2009 Canonical Ltd.
#
# This file is part of wsgi-oops.
#
# wsgi-oops is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation.
#
# wsgi-oops is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with wsgi-oops.  If not, see <http://www.gnu.org/licenses/>.

""" Tests for Oops Logging Handler """

import logging
from os import listdir
from os.path import join as path_join
import shutil
import sys
import unittest

from storm.tracer import install_tracer

from canonical import oops
from canonical.oops.stormtracer import OOPSStorm, OOPSStormTracer
from canonical.oops.oops import OOPS, OOPSLog, OOPSLoggingHandler
from canonical.oops.serializer  import OOPSFileSerializer

OOPSPATH = path_join(oops.__path__[0], 'tests', 'oops')


class OopsLoggingHandlerTests(unittest.TestCase):
    """Test oops serialisers"""

    def setUp(self):
        """Init this test"""
        for d in listdir(OOPSPATH):
            shutil.rmtree(path_join(OOPSPATH, d))
        self.serializer = OOPSFileSerializer('logging', OOPSPATH)
        self.oops = OOPS(self.serializer.get_next_oops_id)
        self.oops.add(OOPSLog())
        self.oops.add(OOPSStorm())
        install_tracer(OOPSStormTracer())
        self.logger = logging.getLogger()
        self.logger.addHandler(OOPSLoggingHandler(serializer=self.serializer,
                                                  oops=self.oops))

    def test_logging_handler(self):
        """The actual test"""
        try:
            raise ValueError, "Error!"
        except ValueError:
            self.failUnless(len(self.oops.get_all())==2)
            # the folder is empty
            self.failUnless(listdir(OOPSPATH)==[])
            logging.error("Test Error", exc_info=sys.exc_info())
            # the folder contains one oops
            self.failUnless(len(listdir(OOPSPATH))==1)
            
    def tearDown(self):
        """clean up"""
        for d in listdir(OOPSPATH):
            shutil.rmtree(path_join(OOPSPATH, d))


        
if __name__ == '__main__':
    unittest.main()
