# Copyright 2009 Canonical Ltd.
#
# This file is part of wsgi-oops.
#
# wsgi-oops is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation.
#
# wsgi-oops is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with wsgi-oops.  If not, see <http://www.gnu.org/licenses/>.

""" test for canonical.oops.wsgi """
import unittest

from canonical.oops.tests import testcase

class TestSimpleWSGIOops(testcase.WSGIOopsTestCase):
    """ simple test of wsgi oops just test for all ok and error """

    def test_simple_error(self):
        """ test an error from the application and check if
        there is an oopsid assigned
        """
        res = self.testapp.get('?error=forced_error',
                    status=500,
                    expect_errors=True)
        self.assertNotEquals(None, self.oops.id)
        self.assertTrue(self.oops.wanted)

    def test_all_ok(self):
        """ test the all ok path """
        res = self.testapp.get('?ok=all_ok', status=200, expect_errors=False)
        self.assertNotEquals(None, self.oops.id)
        self.assertFalse(self.oops.wanted)


class TestEnvironWSGIOops(testcase.WSGIOopsTestCase):
    """Create the oops enviroment for testing"""
    def create_test_app(self):
        """Create a useful test app for the wsgi testing."""
        def test_app(environ, start_response):
            """ simple wsgi app that returns a 500 error
            if can't find OOPSID in environ
            """
            if environ.get('OOPSID', None) is None:
                start_response("500 Missing OOPSID in environ",
                            [('Content-Type', 'text/html'),])
            else:
                start_response("200 OK", [('Content-Type', 'text/html'), ])
            return ['Avant!']
        return test_app

    def test_oopsid_in_environ(self):
        """ test that OOPSID is in the environ """
        res = self.testapp.get('?ok=all_ok', status=200, expect_errors=False)


if __name__ == '__main__':
    unittest.main()

